package de.intevation.flys.artifacts.model.fixings;

import org.apache.log4j.Logger;

import de.intevation.artifacts.Artifact;
import de.intevation.artifacts.CallContext;

import de.intevation.flys.artifacts.FLYSArtifact;
import de.intevation.flys.artifacts.model.DataFacet;
import de.intevation.flys.artifacts.model.FacetTypes;
import de.intevation.flys.artifacts.model.WQKmsFactory;
import de.intevation.flys.artifacts.access.FixRealizingAccess;

import de.intevation.flys.artifacts.states.DefaultState.ComputeType;


/**
 * Facet to show W|Q|km Values.
 */
public class FixEventFacet
extends      DataFacet
implements   FacetTypes {

    /** House logger. */
    private static Logger logger = Logger.getLogger(FixEventFacet.class);


    public FixEventFacet(int index, String name, String description) {
        super(index, name, description, ComputeType.FEED, null, null);
    }


    /**
     * Returns the data this facet requires.
     *
     * @param artifact the owner artifact.
     * @param context  the CallContext (ignored).
     *
     * @return the data.
     */
    @Override
    public Object getData(Artifact artifact, CallContext context) {
        logger.debug("FixEventFacet.getData");

        FixRealizingAccess access = new FixRealizingAccess((FLYSArtifact) artifact, context);
        int wstColID = access.getEvents()[index];
        return WQKmsFactory.getWQKmsCID(wstColID);
    }


    /**
     * Create a deep copy of this Facet.
     * @return a deep copy.
     */
    @Override
    public FixEventFacet deepCopy() {
        FixEventFacet copy = new FixEventFacet(index, name, description);
        copy.set(this);
        return copy;
    }
}
// vim:set ts=4 sw=4 si et sta sts=4 fenc=utf8 :
